@@ -60,6 +60,7 @@ class STT(object):
       c) a tuple ``(QuadType,span)`` where ``QuadType`` is one of the quadrature rules available in :py:mod:`SpectralToolbox.Spectral1D` without the selection of a particular polynomial type, and ``span`` is defined as above.
     :param object params: any list of parameters to be passed to the function ``f``
     :param int range_dim: define the dimension of the spatial dimension ``Is``. For functionals ``f(theta,params)``, ``dim(Is)=0``. For scalar fileds in 3D, ``dim(Is)=3``.
+    :param bool marshall_f: whether to marshall the function f or not. For MPI support, the function f must be marshallable (does this adverb exists??).
     :param bool surrogateONOFF: whether to construct the surrogate or not
     :param str surrogate_type: whether the surrogate will be an interpolating surrogate (``TensorTrain.LINEAR_INTERPOLATION`` or ``TensorTrain.LAGRANGE_INTERPOLATION``) or a projection surrogate (``TensorTrain.PROJECTION``)
     :param list orders: polynomial orders for each dimension if ``TensorTrain.PROJECTION`` is used. If ``orderAdapt==True`` then the ``orders`` are starting orders that can be increased as needed by the construction algorithm. If this parameter is not provided but ``orderAdapt==True``, then the starting order is 1 for all the dimensions.
@@ -83,6 +84,7 @@ class STT(object):
     Xs_params = None            # np.array of List of points (defining the parameter grid)
     Ws = None                   # np.array of List of weights
 
+    marshall_f = None           # Whether to marshall the function or not
     surrogateONOFF = None       # Whether to construct the surrogate or just the tt-approximation
     surr_type = None            # Can be Projection or Interpolation
     orders = None               # np.array of orders for each point
@@ -118,14 +120,14 @@ class STT(object):
     stop_build_time = None
     last_store_time = None
 
-    serialize_list = ['TTapprox', 'TTfour', 'Xs_space', 'space_shape', 'Xs_params', 'Ws', 'poly_Ws', 'Vs', 'barycentric_weights', 'surrogateONOFF', 'surr_type', 'orders', 'poly_types', 'poly_params', 'quad_types', 'poly_Xs', 'spans', 'range_dim', 'param_dim', 'params', 'stt_store_location', 'stt_store_freq', 'eps', 'lr_r', 'lr_fix_rank', 'lr_Jinit', 'lr_delta', 'lr_maxit', 'mv_eps', 'mv_maxit', 'init']
+    serialize_list = ['TTapprox', 'TTfour', 'Xs_space', 'space_shape', 'Xs_params', 'Ws', 'poly_Ws', 'Vs', 'barycentric_weights', 'surrogateONOFF', 'surr_type', 'orders', 'poly_types', 'poly_params', 'quad_types', 'poly_Xs', 'spans', 'range_dim', 'param_dim', 'params', 'stt_store_location', 'stt_store_freq', 'eps', 'lr_r', 'lr_fix_rank', 'lr_Jinit', 'lr_delta', 'lr_maxit', 'mv_eps', 'mv_maxit', 'init','marshall_f']
     subserialize_list = ['TW']
     
     # Parameters to be reset on restarting
     f = None                    # Function to be approximated
     polys = None                # List of polynomials (Spectral1D.Poly1D)
     
-    def __init__(self, f, grids, params, range_dim=0,
+    def __init__(self, f, grids, params, range_dim=0, marshall_f=True,
                  surrogateONOFF=False, surrogate_type=None, orders=None, orderAdapt=None, 
                  eps=1e-4,
                  lr_r=None, lr_fix_rank=False, lr_Jinit= None, lr_delta=1e-4, lr_maxit=100, 
@@ -138,6 +140,7 @@ class STT(object):
         
         self.f = f
         self.params = params
+        self.marshall_f = marshall_f
         self.surrogateONOFF = surrogateONOFF
         self.surr_type = surrogate_type
         self.stt_store_location = stt_store_location
@@ -173,10 +176,11 @@ class STT(object):
         if   self.range_dim == 0: dtype = np.float64
         elif self.range_dim > 0: dtype = np.ndarray
         self.TW = TensorWrapper(self.f, \
-                                    self.Xs_params[tuple([0]*max(self.range_dim,1))],\
-                                    params = self.params, \
-                                    dtype = dtype, \
-                                    store_file = self.stt_store_location, store_object = self)
+                                self.Xs_params[tuple([0]*max(self.range_dim,1))],\
+                                params = self.params, \
+                                dtype = dtype, \
+                                store_file = self.stt_store_location, store_object = self,
+                                marshall_f=marshall_f)
         
         # Start construction
         self.build(maxprocs)
@@ -196,7 +200,7 @@ class STT(object):
         self.TW = tw
         
         # Reset additional parameters
-        self.set_f(f)
+        self.set_f(f,self.marshall_f)
         self.TW.store_object = self
         self.polys = [None for i in range(self.param_dim)]
         for i, (poly_type, poly_param) in enumerate(zip(self.poly_types,self.poly_params)):
@@ -397,16 +401,16 @@ class STT(object):
     def copy(self):
         C = copy.deepcopy(self)
         # Reset additional parameters
-        C.set_f(self.f)
+        C.set_f(self.f,self.marshall_f)
         C.polys = [None for i in range(self.param_dim)]
         for i, (poly_type, poly_param) in enumerate(zip(self.poly_types,self.poly_params)):
             if poly_type != None:
                 C.polys[i] = S1D.Poly1D(poly_type,poly_param)
         return C
  
-    def set_f(self,f):
+    def set_f(self,f,marshall_f=True):
         self.f = f
-        self.TW.set_f(self.f)
+        self.TW.set_f(self.f,marshall_f)
 
     def set_grids(self,grids,orders=None):
         # Store grid for spatial space
@@ -489,7 +493,11 @@ class STT(object):
         self.TW.set_maxprocs(maxprocs) # Set the number of processors for MPI
         for point, val in np.ndenumerate(self.TTapprox):
             if val == None or not val.init:
-                print "Point %s - Fill: %f%%" % (str(point),float(self.TW.get_fill_level())/float(self.TW.get_size()) * 100.)
+                try:
+                    totsize = float(self.TW.get_size())
+                    print "Point %s - Fill: %f%%" % (str(point),float(self.TW.get_fill_level())/totsize * 100.)
+                except OverflowError:
+                    print "Point %s - Fill: %d" % (str(point),self.TW.get_fill_level())
                 multidim_point = point if self.range_dim > 0 else None
                 # Build TTapprox for the selected point
                 if val == None or self.TTapprox[point].ttcross_Jinit == None:
