@@ -538,7 +538,16 @@ class TTvec(object):
         if store_init: self.ttcross_Jinit = lr_Jinit
         
         Gold = [ np.zeros((lr_r[k],n[k],lr_r[k+1])) for k in range(d) ]
-        Gnew = [ npr.random((lr_r[k],n[k],lr_r[k+1])) * 1000. for k in range(d) ]
+        Gnew = [ npr.random((lr_r[k],n[k],lr_r[k+1])) for k in range(d) ]
+        
+        # Normalize Gnew so that we enter the first loop and check for inf or 0. value
+        tt_Gnew = TTvec(Gnew)
+        fro_new = mla.norm(tt_Gnew,'fro')
+        if fro_new == np.inf or fro_new == 0.:
+            raise OverflowError("TensorToolbox.TensorTrainVec: The Frobenious norm of the init TT is: %f" % fro_new )
+        tt_Gnew = tt_Gnew * (1./fro_new)
+        Gnew = tt_Gnew.TT
+        
         Js = lr_Jinit
 
         self.ltor_fiber_lists = []
@@ -548,7 +557,11 @@ class TTvec(object):
         while lr_it < lr_maxit and mla.norm(TTvec(Gold)-TTvec(Gnew),'fro') > lr_delta * mla.norm(TTvec(Gnew), 'fro'):
             lr_it += 1
             if isinstance(A,TensorWrapper) and A.twtype == 'array':
-                sys.stdout.write("Ranks: %s - Iter: %d - Fill: %e%%\r" % (str(lr_r),lr_it , float(A.get_fill_level())/float(A.get_size()) * 100.) )
+                try:
+                    totsize = float(A.get_size())
+                    sys.stdout.write("Ranks: %s - Iter: %d - Fill: %e%%\r" % (str(lr_r),lr_it , float(A.get_fill_level())/totsize * 100.) )
+                except OverflowError:
+                    sys.stdout.write("Ranks: %s - Iter: %d - Fill: %d\r" % (str(lr_r),lr_it , A.get_fill_level()) )
             else:
                 sys.stdout.write("Ranks: %s - Iter: %d \r" % (str(lr_r),lr_it) )
             sys.stdout.flush()
@@ -562,7 +575,11 @@ class TTvec(object):
             Is = [[()]]
             for k in range(d-1):
                 if isinstance(A,TensorWrapper) and A.twtype == 'array':
-                    sys.stdout.write("Ranks: %s - Iter: %d - LR: %d - Fill: %e%%\r" % (str(lr_r),lr_it,k, float(A.get_fill_level())/float(A.get_size()) * 100.) )
+                    try:
+                        totsize = float(A.get_size())
+                        sys.stdout.write("Ranks: %s - Iter: %d - LR: %d - Fill: %e%%\r" % (str(lr_r),lr_it,k, float(A.get_fill_level())/totsize * 100.) )
+                    except OverflowError:
+                        sys.stdout.write("Ranks: %s - Iter: %d - LR: %d - Fill: %d\r" % (str(lr_r),lr_it,k, A.get_fill_level()) )
                 else:
                     sys.stdout.write("Ranks: %s - Iter: %d - LR: %d \r" % (str(lr_r),lr_it,k))
                 sys.stdout.flush()
@@ -622,7 +639,11 @@ class TTvec(object):
             Js[-1] = [()]
             for k in range(d,1,-1):
                 if isinstance(A,TensorWrapper) and A.twtype == 'array':
-                    sys.stdout.write("Ranks: %s - Iter: %d - RL: %d - Fill: %e%%\r" % (str(lr_r),lr_it,k, float(A.get_fill_level())/float(A.get_size()) * 100.) )
+                    try:
+                        totsize = float(A.get_size())
+                        sys.stdout.write("Ranks: %s - Iter: %d - RL: %d - Fill: %e%%\r" % (str(lr_r),lr_it,k, float(A.get_fill_level())/totsize * 100.) )
+                    except OverflowError:
+                        sys.stdout.write("Ranks: %s - Iter: %d - RL: %d - Fill: %d\r" % (str(lr_r),lr_it,k, A.get_fill_level()) )
                 else:
                     sys.stdout.write("Ranks: %s - Iter: %d - RL: %d \r" % (str(lr_r),lr_it,k))
                 sys.stdout.flush()
