@@ -136,6 +136,15 @@ if (0 in RUNTESTS) or opt == 'c':
     ########################################
     # Multi-Linear Algebra
     ########################################
+    
+    # Sum by scalar
+    CPa = DT.Candecomp([5.*np.ones((1,5)),np.ones((1,6)),np.ones((1,7))])
+    TTa = DT.TTvec(CPa,1e-13)
+    TTb = TTa + 3.
+    if np.abs(TTb[3,3,3] - 8.) < 1e-12:
+        print_ok("0.2 Tensor Test: TT sum by scalar")
+    else:
+        print_fail("0.2 Tensor Test: TT sum by scalar", "TT[idx] + b = %e, Expected = %e" % (TTb[3,3,3],8.))
 
     # Sum
     C = TT + TT
